import argparse


class UniqueAction(argparse.Action):
    def __call__(self, parser, namespace, values, option_string=None):
        if len(values) != len(set(values)):
            unique = set()
            duplicated = set()
            for x in values:
                if x not in unique:
                    unique.add(x)
                else:
                    duplicated.add(x)
            raise argparse.ArgumentError(self, f"Duplicate values: {duplicated}")
        setattr(namespace, self.dest, values)

def base_parser(description):
    parser = argparse.ArgumentParser(description=description)
    parser.add_argument("device", help="Device MAC address.")
    parser.add_argument(
        "-s",
        "--sample-rate",
        default=1000,
        type=int,
        choices=[10, 100, 1000],
        help="Sample rate (Hz).",
    )

    group = parser.add_mutually_exclusive_group(required=True)
    group.add_argument(
        "-p",
        "--ports",
        nargs="+",
        type=int,
        action=UniqueAction,
        help="Active ports: Raw data values.",
    )
    group.add_argument(
        "-t",
        "--types",
        nargs="+",
        action=UniqueAction,
        choices=["emg", "ecg", "eda", "eeg", "acc", "lux"],
        help="Active ports: Transformed data values.",
    )
    return parser
