"""
Transfer functions

Taken from timeflux implementation.
https://github.com/timeflux/timeflux_bitalino
"""

# Working voltage
VCC = 3.3


def ecg(signal, resolution=10):
    """ECG value in millivolt [-1.5𝑚𝑉, 1.5𝑚𝑉]"""
    return (((signal / 2 ** resolution) - 0.5) * VCC) / 1100 * 1000


def emg(signal, resolution=10):
    """EMG value in millivolt [-1.64𝑚𝑉, 1.64𝑚𝑉]"""
    return (((signal / 2 ** resolution) - 0.5) * VCC) / 1009 * 1000


def eda(signal, resolution=10):
    """EDA value in microsiemens [0𝜇𝑆, 25𝜇𝑆]"""
    return ((signal / 2**resolution) * VCC) / 0.132


def eeg(signal, resolution=10):
    """EEG value in microvolts [-39.49𝜇𝑉, 39.49𝜇𝑉]"""
    return (((signal / 2**resolution) - 0.5) * VCC) / 41782 * 1e6


def acc(signal, resolution=10):
    """ACC value in percents [-50%, 50%]"""
    return pzt(signal, resolution)


def lux(signal, resolution=10):
    """LUX value in unit norm range [0, 1]"""
    return unit_norm(signal, resolution)

def unit_norm(signal, resolution=10):
    """Unit normalisation [0, 1]"""
    return signal / 2**resolution


def pzt(signal, resolution=10):
    """Percents scale [-50%, 50%]"""
    return (unit_norm(signal, resolution) - 0.5) * 100
